@@ -1,22 +1,18 @@
 package Net::DNS::RR::AAAA;
 
-#
-# $Id: AAAA.pm 1597 2017-09-22 08:04:02Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: AAAA.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::AAAA - DNS AAAA resource record
 
 =cut
 
-
 use integer;
 
 
@@ -25,20 +21,21 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 	my ( $data, $offset ) = @_;
 
 	$self->{address} = unpack "\@$offset a16", $$data;
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	pack 'a16', $self->{address};
+	return pack 'a16', $self->{address};
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	$self->address_short;
+	return $self->address_short;
 }
 
 
@@ -46,23 +43,23 @@ sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->address(shift);
+	return;
 }
 
 
 sub address_long {
-	my $addr = pack 'a*@16', grep defined, shift->{address};
-	sprintf '%x:%x:%x:%x:%x:%x:%x:%x', unpack 'n8', $addr;
+	my $addr = pack 'a*@16', grep {defined} shift->{address};
+	return sprintf '%x:%x:%x:%x:%x:%x:%x:%x', unpack 'n8', $addr;
 }
 
 
 sub address_short {
-	my $addr = pack 'a*@16', grep defined, shift->{address};
-	for ( sprintf ':%x:%x:%x:%x:%x:%x:%x:%x:', unpack 'n8', $addr ) {
-		s/(:0[:0]+:)(?!.+:0\1)/::/;			# squash longest zero sequence
-		s/^:// unless /^::/;				# prune LH :
-		s/:$// unless /::$/;				# prune RH :
-		return $_;
-	}
+	my $addr = pack 'a*@16', grep {defined} shift->{address};
+	local $_ = sprintf ':%x:%x:%x:%x:%x:%x:%x:%x:', unpack 'n8', $addr;
+	s/(:0[:0]+:)(?!.+:0\1)/::/;				# squash longest zero sequence
+	s/^:// unless /^::/;					# prune LH :
+	s/:$// unless /::$/;					# prune RH :
+	return $_;
 }
 
 
@@ -71,7 +68,7 @@ sub address {
 
 	return address_long($self) unless scalar @_;
 
-	my $addr = shift;
+	my $addr  = shift;
 	my @parse = split /:/, "0$addr";
 
 	if ( (@parse)[$#parse] =~ /\./ ) {			# embedded IPv4
@@ -83,7 +80,7 @@ sub address {
 
 	# Note: pack() masks overlarge values, mostly without warning.
 	my @expand = map { /./ ? hex($_) : (0) x ( 9 - @parse ) } @parse;
-	$self->{address} = pack 'n8', @expand;
+	return $self->{address} = pack 'n8', @expand;
 }
 
 
@@ -94,9 +91,9 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name IN AAAA address');
+    $rr = Net::DNS::RR->new('name IN AAAA address');
 
-    $rr = new Net::DNS::RR(
+    $rr = Net::DNS::RR->new(
 	name	=> 'example.com',
 	type	=> 'AAAA',
 	address => '2001:DB8::8:800:200C:417A'
@@ -154,7 +151,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
